/*******************************************************************************
 *
 *  FILE NAME: ISCP_PARMS.h 
 *
 *  PURPOSE:   Contains all ISCP constants.  
 *
 *  AUTHOR:     Y.Ou
 *
 *  COPYRIGHT (c) 2001-2015 HONEYWELL INTERNATIONAL INC., ALL RIGHTS RESERVED
 *
 ******************************************************************************/

#ifndef INCLUDED_ISCP_PARMS_H                /* Has this file been included before?  */
#define INCLUDED_ISCP_PARMS_H                /* No, remember it has been now         */
#pragma once


///////////////////////////////////////////////////////////////////////////////////////
  // NAK -    <STX><SN><NAK><parameter><ETX> where <SN> is 1 byte
  // ACK -    <STX><SN><ACK><parameter=00><ETX>
  // BUSY -   <STX><SN><BUSY><parameter=00><ETX>
  // RESEND - <STX><SN><RESEND><00><ETX>

  // Special Frame: 
  // ABORT -  <STX> <SN> <ABRT> <0x00> <ETX>     generated from Host
  // ABORT DONE: <STX> <SN> <ADNE> <0x00> <ETX>  generated from SE

  // High Level Configuration and Status Commands

  // High Level Request Responses are:
  // Setup reply: <STX><SN><SRP> <SG><SID><parameter><SG><SID><parameter>...<FM><CHK><ETX>
  // RESULT:      <STX><SN><RSLT><RID>[parameter]<RID>[parameter]...<FM><CHK><ETX>
  // Status reply:<STX><SN><STRP><STG><STID><parameter><STG><STID><parameter>...<FM><CHK><ETX>
  // Setup permission reply:
  //              <STX><SN><SPRP><SG><SID><permission><SG><SID><permission>...<FM><CHK><ETX>

  // Control command:
  // <STX> <SN> <CMD> <CG> <CID> [parameters] <CG> <CID> [parameters]...<FM> <CHK> <ETX>

  //Barcode data:
  //<STX> <SN> <BCDD> <length> <barcode data> <length> <barcode data>...<FM> <CHK> <ETX>
  //length = number of bytes in the field barcode data (1 word)

  //Event notification:
  //<STX> <SN> <EVNT> <EG> <EID> [parameter] <EG> <EID> [parameter]...<FM> <CHK> <ETX>

  //Setup barcode data:
  //<STX> <SN> <SBCD> <length> <setup barcode data>...<FM> <CHK> <ETX>

////////////////////////////////////////////////////////////////
//  #INCLUDES   
//      NONE
//
////////////////////////////////////////////////////////////////
//  #DEFINES 
/////////////////////////////////////////////////////////////////////////////////////////
// Frame Management Bits
//  bit 7 = reserved
//      6 = multi-frame bit(last frame)
//      5 = multi-frame bit(first frame)
//      4 = reserved
//      3 = restart, used to indicate power-on or restart
//      2 = reserved
//      1 = reserved
//      0 = frame number. Value must be alternate between 0 and 1 for different consecutive
//          frames to detects incorrect frame transmission.
// New FM bits as 12/13/01

// Frame Management Bits
//  bit 7 = reserved, always 0
//      6 = multi-frame bit(last frame)
//      5 = multi-frame bit(first frame)
//      4 = error
//      3 = restart, used to indicate power-on or restart
//      2, 1, 0. frame number.
///////////////////////////////////////////////////////////////////////////////////////////

#define MULTI_FRAME_MASK 0x60               // Bits 5 & 6 are set
#define FRAME_NUM_MASK   0x07               // Bits 0,1,2
#define ERROR_BIT_MASK   0x10               // Bit 4
#define MAX_BC_LABEL_LEN 5000               // Max Datamatrix length is over 3,000 characters. 
#define MAX_FRAME_SIZE   128                // Max ISCP Frame Size
#define  STX_CHAR 0x02
#define  ETX_CHAR 0x03

// Frame Types
#define NAK 0x15
#define ACK 0x06
#define BUSY 0x1B 
#define RESEND 0x05

// Type for Special Frame
#define ABORT_SPI		0x17
#define ABORT			0x18
#define ABORT_DONE		0x04
#define ABORT_SPI_DONE  0x0D
#define AUTOSYNCD		0x0C
#define AUTOSYNC 		0x16

// TYPE for Request from host
#define SETUP_READ				0x40
#define SETUP_WRITE				0x41
#define CONTROL_COMMAND			0x42
#define STATUS_READ				0x43
#define SETUP_PERMISSION_READ   0x44
#define SETUP_PERMISSION_WRITE  0x45
#define SETUP_RANGE_READ		0x46
#define CONTROL_RANGE_READ		0x47
#define IMAGE_DATA_READ			0x70

// High Level Frame Type Generated by SE:
//   response to host: 0x50..0x54
//   asynchronous    : 0x60..0x62

// TYPE for Synchrounous responses 
#define SETUP_REPLY				0x50
#define RESULT					0x51
#define STATUS_REPLY			0x53
#define SETUP_PERMISSION_REPLY	0x54
#define SETUP_RANGE_REPLY		0x55
#define CONTROL_RANGE_REPLY		0x56
#define IMAGE_DATA_REPLY		0x72

// TYPE for Asynchrous responses
#define BARCODE_DATA			0x60
#define EVENT_NOTIFICATION		0x61
#define SETUP_BARCODE_DATA		0x62
#define BARCODE_DATA_EX			0x63
#define BARCODE_DATA_EX2		0x64
#define IMAGE_DATA				0x71


// RESULT FRAME: The RID followed after the TYPE has the following IDs
#define RESULT_ID_DONE				0x00
#define RESULT_ID_UNKNOW_FRAME_TYPE 0x01
#define RESULT_ID_GROUP_UNKNOWN		0x81
#define RESULT_ID_IDENT_UNKNOWN		0x82
#define RESULT_ID_INVALID_PARM		0x83



// Parameters
#define PERMISSION_UNLOCKED 0x00
#define PERMISSION_LOCKED   0x01
#define MULTI_FRAME_ERROR   0x20
#define FRAME_NUMBER_ERROR  0x30
#define CHECKSUM_ERROR      0x50 
#define ISCP_NO_ERROR       0x00
// ISCP's Disable and Enable. For example disable code 93 or enable code 93
#define DISABLE   0x00
#define ENABLE    0x01
#define IPRM_EV_PREEASYSETLABEL   0x44


//
// GID's not included in STCGidFid.h
//
//#define   GID_TS			0x70	/* Trigger settings		*/
//#define   GID_BLI			0x72	/* Beep Led Indicator	*/
#define   GID_GET_ALL_CONFIG_ITEMS 0x00
#define   GID_SI			0x63	/* Serial Interface		*/
// #define	  GID_PROTOCOL		0x61	/* Protocol				*/
//#define	  GID_BLUETOOTH		0x66	/* Bluetooth			*/
//#define	  GID_BLUETOOTH_EX	0xFF	/* Extended bluetooth commands */

#define GID_CONFIG_STATUS   0x40     /* Configuration Status */
#define GID_VFA				0x80	/* Viewfinder app */

// #define GID_SYSTEM			0x75	/* For Read Ahead Mode */

#define SYS_READAHEADMODE	0x41	/* Read Ahead Mode */
#define ENABLE_NON_READAHEADMODE	0x01
#define DISABLE_NON_READAHEADMODE	0x00


/* Codabar group */
#define NW7_ACTIVE			0x40
#define NW7_STARTSTOPTX		0x58
#define NW7_CLSI			0x59
#define NW7_CMARK			0x48
#define NW7_UDSI			0xC0 /* Up to 4 bytes custom symb id */
#define NW7_CHK				0x4C
#define NW7_CHKTX			0x54
#define NW7_CONCTX			0x5A
#define NW7_CONCTYPE		0x5B
#define NW7_LENGTHL1		0x50
#define NW7_LENGTHL2		0x51
#define NW7_LENGTHL3		0x52
#define NW7_LENGTHMODE		0x53

/* Code 93 group */
#define C93_ACTIVE			0x40
#define C93_CMARK			0x48
#define C93_UDSI			0xC0 /* Up to 4 bytes custom symb id */
#define C93_LENGTHL1		0x50
#define C93_LENGTHL2		0x51
#define C93_LENGTHL3		0x52
#define C93_LENGTHMODE		0x53

/* Code 39 group */
#define	C39_ACTIVE			0x40
#define	C39_TRIOPTIC_ACTIVE	0x41
#define C39_FULLASCII		0x5A
#define C39_READING			0x47
#define C39_STARTSTOPTX		0x58
#define C39_STARTCHAR		0x59
#define C39_CMARK			0x48
#define C39_UDSI			0xC0 /* Up to 4 bytes custom symb id */
#define C39_TRIOPTIC_UDSI	0xC1
#define C39_CHK				0x4C
#define C39_CHKTX			0x54
#define C39_RTOL			0x4F
#define C39_LENGTHL1		0x50
#define C39_LENGTHL2		0x51
#define C39_LENGTHL3		0x52
#define C39_LENGTHMODE		0x53

/* Code 128 group */
#define C128_ACTIVE			0x40
#define C128_GS1_128ID		0x58
#define C128_FNC1			0x59
#define C128_ISBT			0x41
#define C128_EAN128_ACTIVE  0x42
#define C128_ISBTCONCTX		0x5A
#define C128_ISBT_CAP		0x5B
#define C128_CMARK			0x48
#define C128_CHK			0x4C
#define C128_RTOL			0x4F
#define C128_LENGTHL1		0x50
#define C128_LENGTHL2		0x51
#define C128_LENGTHL3		0x52
#define C128_LENGTHMODE		0x53
#define C128_UDSI			0xC0
#define EAN128_UDSI			0xC1

/* Code 2 of 5 group */
#define C25I_ACTIVE			0x40
#define C25I_CMARK			0x48
#define C25I_UDSI			0xC0 /* Up to 4 bytes custom symb id */
#define C25I_CHK			0x4C
#define C25I_CHKTX			0x54
#define C25I_LENGTHL1		0x50
#define C25I_LENGTHL2		0x51
#define C25I_LENGTHL3		0x52
#define C25I_LENGTHMODE		0x53

/* Code Matrix 2 of 5 group */
#define C25M_ACTIVE			0x40
#define C25M_CMARK			0x48
#define C25M_UDSI			0xC0 /* Up to 4 bytes custom symb id */
#define C25M_CHK			0x4C
#define C25M_CHKTX			0x54
#define C25M_LENGTHL1		0x50
#define C25M_LENGTHL2		0x51
#define C25M_LENGTHL3		0x52
#define C25M_LENGTHMODE		0x53

/* Code MSI group */
#define MSI_ACTIVE			0x40
#define MSI_CMARK			0x48
#define MSI_UDSI			0xC0 /* Up to 4 bytes custom symb id */
#define MSI_CHK				0x4C
#define MSI_CHKTX			0x54
#define MSI_LENGTHL1		0x50
#define MSI_LENGTHL2		0x51
#define MSI_LENGTHL3		0x52
#define MSI_LENGTHMODE		0x53

/* Code PDF417 group */
#define PDF417_ACTIVE		0x40
#define PDF417_MBUFFERED	0x41
#define PDF417_CHTX			0x58
#define PDF417_OFFNTX		0x59
#define PDF417_SCTX			0x5A
#define PDF417_TSTX			0x5B
#define PDF417_STX			0x5C
#define PDF417_ATX			0x5D
#define PDF417_FSTX			0x5E
#define PDF417_CTX			0x5F
#define PDF417_CMARK		0x48
#define PDF417_UDSI			0xC0 /* Up to 4 bytes custom symb id */

#define uPDF417_ACTIVE		0x42
#define uPDF417_CMARK		0x48
#define uPDF417_C128        0x45
#define uPDF417_UDSI		0xC1


/* Code Plessey group */
#define PLS_ACTIVE			0x40
#define PLS_CMARK			0x48
#define PLS_UDSI			0xC0 /* Up to 4 bytes custom symb id */
#define PLS_CHKTX			0x54
#define PLS_LENGTHL1		0x50
#define PLS_LENGTHL2		0x51
#define PLS_LENGTHL3		0x52
#define PLS_LENGTHMODE		0x53

/* Code Standart 2 of 5 group */
#define C25_ACTIVE			0x40
#define C25_FORMAT			0x58
#define C25_CMARK			0x48
#define C25_UDSI			0xC0 /* Up to 4 bytes custom symb id */
#define C25_CHK				0x4C
#define C25_CHKTX			0x54
#define C25_LENGTHL1		0x50
#define C25_LENGTHL2		0x51
#define C25_LENGTHL3		0x52
#define C25_LENGTHMODE		0x53

/* Code Telepen group */
#define TLP_ACTIVE			0x40
#define TLP_FORMAT			0x58
#define TLP_CMARK			0x48
#define TLP_UDSI			0xC0 /* Up to 4 bytes custom symb id */
#define TLP_LENGTHL1		0x50
#define TLP_LENGTHL2		0x51
#define TLP_LENGTHL3		0x52
#define TLP_LENGTHMODE		0x53

/* Code 11 group */
#define C11_ACTIVE			0x40
#define C11_CMARK			0x48
#define C11_UDSI			0xC0 /* Up to 4 bytes custom symb id */
#define C11_CHK				0x4C
#define C11_CHKTX			0x54
#define C11_LENGTHL1		0x50
#define C11_LENGTHL2		0x51
#define C11_LENGTHL3		0x52
#define C11_LENGTHMODE		0x53

/* Codablock group */
#define CDBA_ACTIVE			0x40
#define CDBF_ACTIVE			0x41
#define CDBA_CMARK			0x48
#define CDBF_CMARK			0x49
#define CDBA_UDSI			0xC0 /* Up to 4 bytes custom symb id */
#define CDBF_UDSI			0xC1 /* Up to 4 bytes custom symb id */

/* Code UPC/EAN group */
#define UPCA_ACTIVE			0x40
#define UPCE_ACTIVE			0x41
#define EAN8_ACTIVE			0x42
#define EAN13_ACTIVE		0x43
#define EAN13_ISBN			0x44
#define ADDON_TX			0x5D
#define ADDON2_ACTIVE		0x45
#define ADDON5_ACTIVE		0x46
#define UPCA_CHKTX			0x54
#define UPCE_CHKTX			0x55
#define EAN8_CHKTX			0x56
#define EAN13_CHKTX			0x57
#define UPCA_NSTX			0x58
#define UPCE_NSTX			0x59
#define UPCA_EAN13			0x5A
#define UPCE_UPCA			0x5B
#define EAN8_EAN13			0x5C
#define UPCA_CMARK			0x48
#define UPCE_CMARK			0x49
#define EAN8_CMARK			0x4A
#define EAN13_CMARK			0x4B
#define UPCA_UDSI			0xC0 /* Up to 4 bytes custom symb id */
#define UPCE_UDSI			0xC1 /* Up to 4 bytes custom symb id */
#define EAN8_UDSI			0xC2 /* Up to 4 bytes custom symb id */
#define EAN13_UDSI			0xC3 /* Up to 4 bytes custom symb id */

/* RSS group */
#define RSS14_ACTIVE		0x40
#define RSSLI_ACTIVE		0x41
#define RSSEX_ACTIVE		0x42
#define RSS14_CMARK			0x48
#define RSSLI_CMARK			0x49
#define RSSEX_CMARK			0x4A
#define RSS14_UDSI			0xC0 /* Up to 4 bytes custom symb id */
#define RSSLI_UDSI			0xC1 /* Up to 4 bytes custom symb id */
#define RSSEX_UDSI			0xC2 /* Up to 4 bytes custom symb id */


/* Misc Symbologies */
#define DTX_ACTIVE			0x40
#define DTX_UDSI			0xC0

#define QR_ACTIVE			0x40
#define QR_UDSI			    0xC0

#define TLC_UDSI			0xC0


#define C49_ACTIVE			0x40
#define C49_UDSI			0xC0

#define C16K_ACTIVE			0x40
#define C16K_UDSI			0xC0

#define MAXI_ACTIVE			0x40
#define MAXI_UDSI			0xC0

#define AZTEC_ACTIVE		0x40
#define AZTEC_UDSI			0xC0


#define UCC_ACTIVE			0x40
#define UCC_C_ACTIVE		0x41
#define UCC_UDSI			0xC0
#define UCC_C_UDSI			0xC1
#define UCC_CMARK			0x48


#define BCC412_UDSI			0xC0
#define BCC412_CMARK		0x48

#define	GID_CHINAPOST       0x37
#define CHINAPOST_ACTIVE    0x40
#define CHINAPOST_UDSI      0xC0
#define CHINAPOST_CMARK     0x48


/* Message Format group */
#define MF_PREAMBLE			0xC0
#define MF_POSTAMBLE		0xC1
#define MF_SYMBID			0x40
#define MF_ICDELAY			0x80
#define MF_IMDELAY			0x81
#define MF_OMOUR			0x41
#define MF_MSG				0xC2

#define MF_SYMBIDDATA_DISABLE 0x00
#define MF_SYMBIDDATA_CUSTID  0x01
#define MF_SYMBIDDATA_AIMID   0x02
#define MF_SYMBIDDATA_UDSIID  0x03


/* Beep/Led Indicator group */
#define BLI_BFREQ			0x80
#define BLI_POWERUP			0x40
#define BLI_NBEEP			0x41
#define BLI_BDURATION		0x81
#define BLI_LDURATION		0x82
#define BLI_AFTERTX			0x42
#define BLI_ERROR			0x43
#define BLI_SETUP			0x44
#define BLI_BVOL			0x45
#define BLI_BCRACKLE			0x46
#define BLI_LFLICKER			0x47
#define BLI_VIBRATE			0x48
#define BLI_VDURATION			0x83
#define BLI_LOWBATTERY			0x49
#define BLI_SUSPEND_ON_LOW_BATTERY	0x4A
#define BLI_USER_INTERFACE		0x4B

/* Decoding Security group */
#define DS_SRDV			0x40
#define DS_TBICC			0x80
#define DS_TBDCC			0x81

/* Serial Interface group */
#define SI_BAUDRATE			0x40
#define SI_RTS				0x41
#define SI_TIMEOUT			0x80
#define SI_NBITS			0x42
#define SI_PARITY			0x43
#define SI_NSTOPBITS		0x44
#define SI_ENQACTIVE		0x45
#define SI_ENQCHAR			0x46
#define SI_ACKACTIVE		0x47
#define SI_ACKCHAR			0x48
#define SI_NACKACTIVE		0x49
#define SI_NACKCHAR			0x4A
#define SI_XONACTIVE		0x4B
#define SI_LRCACTIVE		0x4C

/* Trigger Settings group */
#define TS_TMODE			0x40
#define TS_T1				0x80
#define TS_HTRIGGER			0x41
#define TS_STRIGGER			0x42
#define TS_STARTCHAR		0x43
#define TS_STOPCHAR			0x44
#define TS_AIMERACTIVATION		0x45
#define TS_T2				0x81
#define TS_TOAGR			0x46
#define TS_POWERMODE		0x47
#define TS_T3               0x86
#define TS_TFLASHLIGHT      0x87

/* Image and snapshot settings group */
#define IMG_DOCCAP_READY_EVENT	0x6A
#define IMG_DOCCAP_FAIL_EVENT	0x6B
#define IMG_DOCCAP_SUCCESS_EVENT 0x6C
#define IMG_SIGCAP_SUCCESS_EVENT 0x6D

#define IMG_SS_CONDITION		0xB0
#define IMG_VID_START_CONDITION 0xA0
#define IMG_VID_STOP_CONDITION	0xA1

/* ISCP Configuration group */
#define ISCP_PACKET_FORMAT	0x40	// Parm 0: Raw data format; Parm 1: ISCP Frame data format

/* Viewfinder configuration */
#define VFA_ACTIVE				0x40		// Viewfinder active
#define VFA_DECODE_AUTOCAPTURE	0X41		// Autocapture - optimizes viewfinder performance when decoding enabled.



/* Antares Configuration group */
#define ANTARES_CODABAR_SS_TRANSMIT     0x40    // Codabar start / stop transmit, not used.  Using 40 58 instead
#define ANTARES_CODABAR_CONCAT_SS_XMIT  0x41		// not used
#define ANTARES_EAN128_SYMID            0x42		// EAN 128 symbology ID (Func 1 conversion) enable / disable
#define ANTARES_CODE128_CONCAT			 0x43    // not used
#define ANTARES_ISBT_SYMID              0x44		// ISBT symbology ID enable / disable
#define ANTARES_CODE39_FID_SYMBID		 0x45
#define ANTARES_CODE128_FID_SYMBID		 0x46
#define ANTARES_CODABAR_FID_SYMBID		 0x47
#define ANTARES_CODE93_FID_SYMBID		 0x48
#define ANTARES_CODE11_FID_SYMBID		 0x49
#define ANTARES_I2OF5_FID_SYMBID		    0x4A
#define ANTARES_PDF417_FID_SYMBID		 0x4B
#define ANTARES_MSI_FID_SYMBID			 0x4C
#define ANTARES_PLESSEY_FID_SYMBID		 0x4D
#define ANTARES_2OF5_FID_W2BAR_SYMBID	 0x4E
#define ANTARES_2OF5_FID_W3BAR_SYMBID	 0x4F
#define ANTARES_UPCA_FID_SYMBID			 0x50
#define ANTARES_UPCE_FID_SYMBID			 0x51
#define ANTARES_EAN8_FID_SYMBID			 0x52
#define ANTARES_EAN13_FID_SYMBID		    0x53
#define ANTARES_MAXICODE_FID_SYMBID		 0x54
#define ANTARES_DATAMATRIX_FID_SYMBID	 0x55
#define ANTARES_QRCODE_FID_SYMBID		 0x56
#define ANTARES_UCC_FID_COMP_SYMBID		 0x57
#define ANTARES_RSS14_FID_SYMBID		    0x58
#define ANTARES_RSS_FID_LIMITED_SYMBID  0x59
#define ANTARES_RSS_FID_EXPANDED_SYMBID 0x5A
#define ANTARES_SCANNER_TIME_OUT        0x5B    // not used
#define ANTARES_SCANNER_DATA_BUFFERING  0x5C    // scan ahead, not used
#define ANTARES_DECODE_SECURITY         0x5D		// Decode Security - CSn
#define ANTARES_SCN_REDNDNCY 	          0x5E		// Scanner Redundancy - SRn
#define ANTARES_CASECODE_CK_TX          0x5F		// I2/5 Case code check digit transmission
#define ANTARES_CODABAR_STD_ABC_CONCAT  0x61    // Codabar type: standard, ABC, or Concatenated
#define ANTARES_M2OF5_FID_SYMBID		    0x62
#define ANTARES_TELEPEN_FID_SYMBID		 0x63
#define ANTARES_MICROPDF_FID_SYMBID		 0x64
#define ANTARES_CODABLOCK_FID_A_SYMBID	 0x65
#define ANTARES_CODABLOCK_FID_F_SYMBID	 0x66
#define ANTARES_UPCA_LEAD_ZERO          0x67		// UPC-A leading zero: 0 = discard, 1 = retain
#define ANTARES_CODE128_CONTROL_PARAM   0x80    // not used
#define ANTARES_NO_SYMBID				    0xFF

#define ANTARES_SYMBID_DISABLE			 0x00
#define ANTARES_SYMBID_AIMID			 0x01
#define ANTARES_SYMBID_CUSTOMID			 0x02


/* Bluetooth configuration group */
#define BT_DEVICE_NAME					 0xC2	/* Bluetooth device friendly name. */
#define BT_MAX_RECONNECT_MSECS			 0xC3	/* Maximum time (in msecs) to attempt to reconnect to disconnected BT device. */
#define BT_MAX_RETRY_BACKOFF_MSECS		 0xC4	/* Longest retry time (in msecs) in attempting to reconnected to a disconnected BT device */
#define BT_CLIENT_SERVER				 0xC5	/* Commands device to be a Client or Server.  Use to cause a disconnect */

/* Bluetooth status read group */
#define BT_DEVICE_ADDRESS				 0xC3	/* Blutetooth device address */


/* Configuration group */



/* ISCP Parameters group */
#define RAW_FORMAT   0x00       // Barcode data in raw format
#define ISCP_FORMAT  0x01       // Barcode data enclosed in ISCP frame
#define ISCP_BCDEX2  0x01		// Used with IPRM_BCDFORMAT to specify BCDEX2 format 

#define IPRM_DATAFORMAT		0x40
#define IPRM_BCDFORMAT		0x4E // BCD / BCDEX2 format FID. (param 00 = BCD; 01=BCDEX2)
#define IPRM_TFS			0x80
#define IPRM_EV_SMOD		0x41 // Event - Setup Mod. by Config Barcode
#define IPRM_EV_OSR			0x42
#define IPRM_EV_SCS			0x43
#define IPRM_EV_SCP			0x44
#define IPRM_EV_SCE			0x45
#define IPRM_EV_UD			0x46
#define IPRM_EV_SRS			0x47
#define IPRM_EV_ERS			0x48
#define IPRM_EV_SU			0x49
#define IPRM_EV_TP			0x4A
#define IPRM_EV_TR			0x4B
#define IPRM_EV_BT_DISC		0x4C // Event - Bluetooth Disconnect

/* Protocol group */
#define PROT_TYPE			0x40

/***********************************************************************/
/*****************     CONTROL COMMAND                ******************/
/***********************************************************************/
#define CCID_DECODING			0x20
#define CCID_HARDWARE			0x30
#define CCID_CONFIGURATION		0x40
#define CCID_OPERATING			0x50

/* Decoding group */
#define CMD_RESETSTATS			0x01 // no prm
#define CMD_DECODE				0x40	// prm 1 byte

/* Hardware group */
#define CMD_BUZZER				0xC0	// prm buffer bytes
#define CMD_GREENLED			0x40 // prm 1 byte
#define CMD_BEEPSEQ				0x41 // prm 1 byte
#define CMD_UPFLASH				0x01 // no prm
#define CMD_RESET				0x02 // no prm
#define CMD_SLEEP				0x03 // no prm

/* Configuration group */
#define CMD_UPDATECFG			0x01 // no prm
#define CMD_FACTORYDEFAULT		0x02 // no prm
#define CMD_DISABLE_ALL_SYMB	0x03 // Disable all symbologies. No parameter.
#define CMD_IMGPREDEFINEDMD_CUSTOM		0xFF  // Imager Predefined mode custom
#define CMD_TRGPREDEFINEDCMD    0x51 // Trigger predefined command


/* Operating group */
#define CMD_SILENTMODE			0x40 // prm 1 byte
#define CMD_VIDEOSTART			0x43 // 0: disable; 1: enable


/* New Commands for SF51 Read Ahead Mode */
#define CMD_SCANNERMODE			0x41
#define CMD_PROCEEDCOMMAND		0x44


/***********************************************************************/
/*****************               STATUS               ******************/
/***********************************************************************/
#define STID_DECODING	   0x20
#define STATUS_DECODING	   0xC0
#define STATUS_DECODESTATS 0xC2



#define STID_HARDWARE      0x30

/* Hardware group */
#define STATUS_MRFS        0x80  /* outprm: 1 word */
#define STATUS_MTFS        0x81  /* outprm: 1 word */
#define STATUS_FIRMVERS    0xC0  /* outprm: string */
#define STATUS_FULLVERS    0xC4  /* outprm: string */
#define STATUS_HARDWAREID  0x82  /* outprm: ulong */
#define STATUS_DECODE	   0x22
#define STATUS_GREENLED	   0x23

/* Configuration group */
#define STATUS_TRGPREDEFINEDCMD    0x51 // Trigger predefined status read

/* Operating */
#define STID_OPERATING	   0x50
#define STATUS_TRIG_MODE_VERSION 0x80

/* Camera Imager */
#define STATUS_IMGCONTROLREGISTER_RD        0xD0    // free form command to read image control registers
/***********************************************************************/
/*****************               EVENT                ******************/
/***********************************************************************/
#define EGID_DECODING      0x20
#define EGID_HARDWARE      0x30
#define EGID_CONFIGURATION 0x40
#define EG_LOC_DATA        0x80

// Event Group : Location Data
#define EID_LOC_DATA_AVAIL     0xC0   // Location data available event

/* Decoding group */
#define EID_UD			0x20
#define EID_SRS			0x21
#define EID_ERS			0x22

/* Hardware group */
#define EID_SU		   	0x20		// startup
#define EID_TP			0x21		// Trigger pull
#define EID_TR		   	0x22		// Trigger release

/* Configuration group */
#define EID_SMOD		0x80
#define EID_CMDEX		0x81	// Control Command execution.
#define EID_OSR			0x20
#define EID_SCS			0x21
#define EID_SCP			0x22
#define EID_SCE			0x23

/* Bluetooth group */
#define EID_DISCONNECT  0x07

/* Configuration Status */
#define STID_LCS        0xC0   // Last config signature FID

/* EasySet label event */
#define EVTERR_NOERROR		0x00	// No error - EasySet label handled
#define EVTERR_PERMINSSION	0x02	// Permissions error
#define EVTERR_UNKNOWN_GID	0x81	// Unknown GID error
#define EVTERR_UNKNOWN_FID	0x82	// Unknown FID error
#define EVTERR_INVPARAM		0x83	// invalid parameter error

// Event group : Image data
// Best place would be to add in STDGidFid.h
#define EID_SCOK               0xC0    // signature image ready event
#define EID_SCFAILED           0xC1    // signature capture failed
#define EID_DCOK               0xC2    // DocCap image ready event.  Indicates the image is ready to be retrieved.
#define EID_DCFAILED           0xC3    // DocCap failed event.
#define EID_DCSUCCESS		   0xC5	   // DocCap success event.
#define EID_SCSUCCESS		   0xC4	   // SigCap success event.

//
// Each of these are the full ISCP command (GID,FID,value) that can be used during init.
//
/*
static const UCHAR s_rgbSTATUS_MRFS[] = {STID_HARDWARE, STATUS_MRFS};
static const UCHAR s_rgbSTATUS_MTFS[] = {STID_HARDWARE, STATUS_MTFS};

static const UCHAR s_rgbSTATUS_Version[] = {STID_HARDWARE, STATUS_FIRMVERS};
static const UCHAR s_rgbSTATUS_HardWareId[] = {STID_HARDWARE, STATUS_HARDWAREID};
static const UCHAR s_rgbSTATUS_GROUP[] = {STID_HARDWARE, 0x00}; // for retrival the whole group

//
////////////////////////////////////////////////////////////////
//   ENUMS   
typedef enum tagWRITE_STATE
{
     SEND_REQUEST_FRAME,
     WAIT_FOR_LL_FRAME,
     WAIT_FOR_HL_FRAME,
     WAIT_FOR_COMPLETE_WRITE
}WRITE_STATE;

typedef enum tagMultiFrameValue
{
   MULTI_FRAME_OTHER_FRAME, //other frames of a multi-frame msg
   MULTI_FRAME_FIRST_FRAME, //First frame of a multi-frame msg
   MULTI_FRAME_LAST_FRAME,  //Last frame of a multi-frame msg
   MULTI_FRAME_MONO_FRAME,   //Frame of a mono-frame msg
   MULTI_FRAME_BAD_FRAME,
}MULTI_FRAME_VALUE;
////////////////////////////////////////////////////////////////

*/


//
#endif
//
//  END OF FILE:  ISCP_PARMS.h
//  COPYRIGHT (c) 2001 INTERMEC TECHNOLOGIES CORPORATION, ALL RIGHTS RESERVED
//    

